@@ -22,7 +22,7 @@ def _screenMainLoop(s):
         except Empty:
             s.refresh()
 
-        if msg[0] == 'Q':
+        if msg and msg[0] == 'Q':
             return
         elem = s._getElem(msg[0])
         if elem:
